@@ -4,7 +4,7 @@ class CloudWatchLogs {
   constructor (aws, region) {
     // Authenticated `aws` object in `lib/main.js`
     this.lambda = new aws.Lambda({
-      region: region,
+      region,
       apiVersion: '2015-03-31'
     })
     this.cloudwatchlogs = new aws.CloudWatchLogs({
