@@ -51,8 +51,8 @@ Edit the .env, deploy.env, ${program.contextFile}, \
 event_sources.json and ${program.eventFile} files as needed.`)
   }
 
-  run (program) {
-    if (!['nodejs12.x', 'nodejs14.x', 'nodejs16.x'].includes(program.runtime)) {
+  async run (program) {
+    if (!['nodejs14.x', 'nodejs16.x'].includes(program.runtime)) {
       console.error(`Runtime [${program.runtime}] is not supported.`)
       process.exit(254)
     }
@@ -67,7 +67,18 @@ event_sources.json and ${program.eventFile} files as needed.`)
       this._setRunTimeEnvironmentVars(program)
     }
 
-    const handler = require(path.join(process.cwd(), filename))[handlername]
+    const handlerFilePath = (() => {
+      const filePath = path.join(process.cwd(), filename)
+      if (path.sep === '\\') {
+        // Convert because of error in Windows.
+        // Error [ERR_UNSUPPORTED_ESM_URL_SCHEME]:
+        // Only URLs with a scheme in: file, data are supported by the default ESM loader.
+        // On Windows, absolute paths must be valid file:// URLs. Received protocol 'c:'
+        return 'file:///' + filePath.split(path.sep).join('/')
+      }
+      return filePath
+    })()
+    const handler = (await import(handlerFilePath))[handlername]
     const event = require(path.join(process.cwd(), program.eventFile))
     const context = require(path.join(process.cwd(), program.contextFile))
     const enableRunMultipleEvents = (() => {
@@ -364,7 +375,7 @@ Emulate only the body of the API Gateway event.
               return true
             }
 
-            if (!minimatch(src, pattern, { matchBase: true })) {
+            if (!minimatch(src, pattern, { matchBase: true, windowsPathsNoEscape: true })) {
               return true
             }
 
