@@ -35,7 +35,7 @@ class S3Deploy {
   constructor (aws, region) {
     // Authenticated `aws` object in `lib/main.js`
     this.s3 = new aws.S3({
-      region: region,
+      region,
       apiVersion: '2006-03-01'
     })
   }
@@ -133,7 +133,7 @@ class S3Deploy {
   }
 
   putPackage (params, region, buffer) {
-    const _params = Object.assign({ region: region }, params)
+    const _params = Object.assign({ region }, params)
     _params.bucketName = this._bucketName(_params)
     _params.s3Key = this._s3Key(_params)
 
